@@ -17,12 +17,7 @@ import (
 
 var log = clog.NewWithPlugin("dnssec")
 
-func init() {
-	caddy.RegisterPlugin("dnssec", caddy.Plugin{
-		ServerType: "dns",
-		Action:     setup,
-	})
-}
+func init() { plugin.Register("dnssec", setup) }
 
 func setup(c *caddy.Controller) error {
 	zones, keys, capacity, splitkeys, err := dnssecParse(c)
